import numpy as np
import matplotlib.pyplot as plt
from rk4 import rk4


P_MEH = 1
PM_1 = 2.26
PM_2 = 0
PM_3 = 1.603
M = 3.7e-4
T_ISKL = 0.17
T_APV = 0.2

# y[0] = omega e izrazena vo elektricni stepeni vo sekunda
# y[1] = teta e izrazena vo elektricni stepeni


def F1(t, y):
    d = np.array([
        P_MEH/M,
        y[0]
    ])
    return d


def F2(t, y):
    d = np.array([
        (P_MEH - PM_3*np.sin(y[1]/180*np.pi))/M,
        y[0]
    ])
    return d


def F3(t, y):
    d = np.array([
        (P_MEH - PM_1*np.sin(y[1]/180*np.pi))/M,
        y[0]
    ])
    return d


def main():
    # rabota so rezim na kusa vrska od 0 do T_ISKL
    [t, y] = rk4(F1, 0, T_ISKL, [0, np.arcsin(P_MEH/PM_1)/np.pi*180], 50)
    # rabota so isklucen vod od 0 do T_APV
    [t1, y1] = rk4(F2, 0, T_APV, y[-1], 50)
    # rabota vo normalen rezim od 0 do 1 sekunda
    [t2, y2] = rk4(F3, 0, 1, y1[-1], 50)
    # trite resenija staveni posledovatelno
    t = np.vstack((t, t1 + T_ISKL, t2 + T_ISKL + T_APV))
    y = np.vstack((y, y1, y2))
    plt.subplot(2, 1, 1)
    plt.plot(t, 50 + y[:, 0]/18000, '-r')
    plt.subplot(2, 1, 2)
    plt.plot(t, y[:, 1], '-b')
    plt.show()


main()
